# Purchasing Power Parity

Online products should be made affordable for everyone around the world. This module is a simple way to make [Purchasing Power Parity](https://en.wikipedia.org/wiki/Purchasing_power_parity) available in your browser.

## How to use it?

**Install:**

`npm install purchasing-power-parity`

**Use:**

```
import getPpp from 'purchasing-power-parity';

let originalPrice = 99.99;
let discountPrice;

getPpp().then(function (ppp) => {
  discountPrice = ppp.pppConversionFactor * originalPrice;
});
```

Adjust your prices when the pppConversionFactor goes below 1. Add an optional banner for your customers to make them aware of it.

<img width="1269" alt="screen shot 2017-10-30 at 14 16 44" src="https://user-images.githubusercontent.com/2479967/32159206-0a4b7bb8-bd7f-11e7-8d60-2eb89a9ec0d1.png">

**ppp-object:**

```
{
  countryCodeIsoAlpha2: "IN",
  countryCodeIsoAlpha3: "IND",
  countryName: "India",
  currenciesCountry: [{
    code: "INR",
    name: "Indian rupee",
    symbol: "₹"
  }],
  currencyMain: {
    exchangeRate: 65.06,
    code: "INR",
    name: "Indian rupee",
    symbol: "₹"
  },
  ppp: 17.536,
  pppConversionFactor: 0.2695358130956041,
}
```

The `currencyMain` property with its `exchangeRate` property is used to compute the `pppConversionFactor` by using the `ppp`.

## Limitations

* runs only in the browser
* so far, onyl takes USD as baseline

## Who uses PPP?

Public statement that you or your company is using PPP to make their products affordable to everyone around the world:

* [Road to React](https://roadtoreact.com/)
* ...

## Contribution

The project is in an early stage, so please feel free to contribute to it. If you want to know how PPP works, you can read up this [short article](https://www.sapling.com/6218206/calculate-purchasing-power-parity). Contribution in three steps:

* create an Issue
* discuss with maintainers and contributors about the issue
* create a Pull Request if the issue should be solved
